@@ -132,7 +132,9 @@ class Hand(object):
         return f'Hand("{self._get_pbn_string()}")'
 
     def __str__(self):
-        return f'Hand("{self._get_pbn_string()}")'
+        sorted_cards = sorted(self._cards, key=lambda x: x.order, reverse=True)
+        cards = [card.name for card in sorted_cards]
+        return f'Hand({", ".join(cards)})'
 
     def __eq__(self, other):
         """Provide eq functionality for hands"""
@@ -518,6 +520,8 @@ class Hand(object):
 
     def sorted_cards(self, suit_order=None, high_card_left=None):
         """Return the card list sorted according to the suit order and high card left."""
+        if not suit_order:
+            suit_order = self._suit_order
         if high_card_left is None:
             high_card_left = self._high_card_left
         return self.sort_card_list(self.cards, suit_order=suit_order, high_card_left=high_card_left)
@@ -599,6 +603,10 @@ class Hand(object):
 
     def _get_suit_lengths(self):
         """Set the number of cards in each suit as an integer."""
+        self._spades = 0
+        self._hearts = 0
+        self._diamonds = 0
+        self._clubs = 0
         for card in self.cards:
             if card.suit == SUITS['S']:
                 self._spades += 1
