@@ -88,8 +88,8 @@ def test_hand_repr():
 
 def test_hand_str():
     """Ensure that the hand str is correct."""
-    assert str(Hand(hand_list_6332)) == 'Hand("J85432.J86.AJ.KJ")'
-    assert str(Hand(hand_pbn_one)) == 'Hand(".63.AKQJ87.A9732")'
+    assert str(Hand(hand_list_6332)) == 'Hand(JS, 8S, 5S, 4S, 3S, 2S, JH, 8H, 6H, AD, JD, KC, JC)'
+    assert str(Hand(hand_pbn_one)) == 'Hand(6H, 3H, AD, KD, QD, JD, 8D, 7D, AC, 9C, 7C, 3C, 2C)'
 
 
 def test_hand_eq():
